# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorRequest(Model):
    """VendorRequest.

    :param vendor_code: The vendor code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type vendor_code: str
    :param vendor_info: The vendor info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type vendor_info: str
    :param website: The vendor's website <span class='property-internal'>Must
     be between 0 and 255 characters</span>
    :type website: str
    :param address: The remit address of the vendor
    :type address: ~energycap.sdk.models.AddressChild
    """

    _validation = {
        'vendor_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'vendor_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'website': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'website': {'key': 'website', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
    }

    def __init__(self, vendor_code, vendor_info, website=None, address=None):
        super(VendorRequest, self).__init__()
        self.vendor_code = vendor_code
        self.vendor_info = vendor_info
        self.website = website
        self.address = address



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowSettings(Model):
    """Represents workflow settings for chargebacks.

    :param allow_advanced_chargeback_settings: Allow or prevent the "advanced"
     dialog to be displayed when running the chargeback processor <span
     class='property-internal'>Required</span>
    :type allow_advanced_chargeback_settings: bool
    """

    _validation = {
        'allow_advanced_chargeback_settings': {'required': True},
    }

    _attribute_map = {
        'allow_advanced_chargeback_settings': {'key': 'allowAdvancedChargebackSettings', 'type': 'bool'},
    }

    def __init__(self, allow_advanced_chargeback_settings):
        super(ChargebackWorkflowSettings, self).__init__()
        self.allow_advanced_chargeback_settings = allow_advanced_chargeback_settings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TaskType(Model):
    """TaskType.

    :param task_type_id: The task type identifier
    :type task_type_id: int
    :param task_type_code: The code for task type
    :type task_type_code: str
    :param task_type_info: The task type information
    :type task_type_info: str
    """

    _attribute_map = {
        'task_type_id': {'key': 'taskTypeId', 'type': 'int'},
        'task_type_code': {'key': 'taskTypeCode', 'type': 'str'},
        'task_type_info': {'key': 'taskTypeInfo', 'type': 'str'},
    }

    def __init__(self, task_type_id=None, task_type_code=None, task_type_info=None):
        super(TaskType, self).__init__()
        self.task_type_id = task_type_id
        self.task_type_code = task_type_code
        self.task_type_info = task_type_info
